# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'starPositionDialog.ui'
#
# Created by: PyQt5 UI code generator 5.12.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(580, 400)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        Dialog.setMinimumSize(QtCore.QSize(580, 400))
        Dialog.setMaximumSize(QtCore.QSize(580, 400))
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(460, 80, 81, 71))
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.label = QtWidgets.QLabel(Dialog)
        self.label.setGeometry(QtCore.QRect(120, 60, 60, 16))
        self.label.setObjectName("label")
        self.label_5 = QtWidgets.QLabel(Dialog)
        self.label_5.setGeometry(QtCore.QRect(310, 60, 60, 16))
        self.label_5.setObjectName("label_5")
        self.layoutWidget = QtWidgets.QWidget(Dialog)
        self.layoutWidget.setGeometry(QtCore.QRect(262, 81, 145, 91))
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.DecDegrees = QtWidgets.QLineEdit(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DecDegrees.sizePolicy().hasHeightForWidth())
        self.DecDegrees.setSizePolicy(sizePolicy)
        self.DecDegrees.setMinimumSize(QtCore.QSize(80, 0))
        self.DecDegrees.setMaximumSize(QtCore.QSize(80, 16777215))
        self.DecDegrees.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.DecDegrees.setObjectName("DecDegrees")
        self.horizontalLayout_4.addWidget(self.DecDegrees)
        self.label_6 = QtWidgets.QLabel(self.layoutWidget)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_4.addWidget(self.label_6)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.DecMinutes = QtWidgets.QLineEdit(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DecMinutes.sizePolicy().hasHeightForWidth())
        self.DecMinutes.setSizePolicy(sizePolicy)
        self.DecMinutes.setMinimumSize(QtCore.QSize(80, 0))
        self.DecMinutes.setMaximumSize(QtCore.QSize(80, 16777215))
        self.DecMinutes.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.DecMinutes.setObjectName("DecMinutes")
        self.horizontalLayout_5.addWidget(self.DecMinutes)
        self.label_7 = QtWidgets.QLabel(self.layoutWidget)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_5.addWidget(self.label_7)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.DecSeconds = QtWidgets.QLineEdit(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DecSeconds.sizePolicy().hasHeightForWidth())
        self.DecSeconds.setSizePolicy(sizePolicy)
        self.DecSeconds.setMinimumSize(QtCore.QSize(80, 0))
        self.DecSeconds.setMaximumSize(QtCore.QSize(80, 16777215))
        self.DecSeconds.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.DecSeconds.setObjectName("DecSeconds")
        self.horizontalLayout_6.addWidget(self.DecSeconds)
        self.label_8 = QtWidgets.QLabel(self.layoutWidget)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_6.addWidget(self.label_8)
        self.verticalLayout_2.addLayout(self.horizontalLayout_6)
        self.label_9 = QtWidgets.QLabel(Dialog)
        self.label_9.setGeometry(QtCore.QRect(90, 20, 341, 16))
        self.label_9.setObjectName("label_9")
        self.label_11 = QtWidgets.QLabel(Dialog)
        self.label_11.setGeometry(QtCore.QRect(30, 200, 511, 71))
        self.label_11.setObjectName("label_11")
        self.layoutWidget1 = QtWidgets.QWidget(Dialog)
        self.layoutWidget1.setGeometry(QtCore.QRect(61, 81, 145, 91))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.RaHours = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RaHours.sizePolicy().hasHeightForWidth())
        self.RaHours.setSizePolicy(sizePolicy)
        self.RaHours.setMinimumSize(QtCore.QSize(80, 0))
        self.RaHours.setMaximumSize(QtCore.QSize(80, 16777215))
        self.RaHours.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.RaHours.setObjectName("RaHours")
        self.horizontalLayout.addWidget(self.RaHours)
        self.label_2 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.RaMinutes = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RaMinutes.sizePolicy().hasHeightForWidth())
        self.RaMinutes.setSizePolicy(sizePolicy)
        self.RaMinutes.setMinimumSize(QtCore.QSize(80, 0))
        self.RaMinutes.setMaximumSize(QtCore.QSize(80, 16777215))
        self.RaMinutes.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.RaMinutes.setObjectName("RaMinutes")
        self.horizontalLayout_2.addWidget(self.RaMinutes)
        self.label_3 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_2.addWidget(self.label_3)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.RaSeconds = QtWidgets.QLineEdit(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RaSeconds.sizePolicy().hasHeightForWidth())
        self.RaSeconds.setSizePolicy(sizePolicy)
        self.RaSeconds.setMinimumSize(QtCore.QSize(80, 0))
        self.RaSeconds.setMaximumSize(QtCore.QSize(80, 16777215))
        self.RaSeconds.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.RaSeconds.setObjectName("RaSeconds")
        self.horizontalLayout_3.addWidget(self.RaSeconds)
        self.label_4 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_3.addWidget(self.label_4)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.layoutWidget2 = QtWidgets.QWidget(Dialog)
        self.layoutWidget2.setGeometry(QtCore.QRect(100, 340, 391, 23))
        self.layoutWidget2.setObjectName("layoutWidget2")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.layoutWidget2)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_10 = QtWidgets.QLabel(self.layoutWidget2)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_7.addWidget(self.label_10)
        self.apiKeyEdit = QtWidgets.QLineEdit(self.layoutWidget2)
        self.apiKeyEdit.setObjectName("apiKeyEdit")
        self.horizontalLayout_7.addWidget(self.apiKeyEdit)
        self.layoutWidget3 = QtWidgets.QWidget(Dialog)
        self.layoutWidget3.setGeometry(QtCore.QRect(30, 280, 471, 23))
        self.layoutWidget3.setObjectName("layoutWidget3")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.layoutWidget3)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_12 = QtWidgets.QLabel(self.layoutWidget3)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_8.addWidget(self.label_12)
        self.singleLineEdit = QtWidgets.QLineEdit(self.layoutWidget3)
        self.singleLineEdit.setObjectName("singleLineEdit")
        self.horizontalLayout_8.addWidget(self.singleLineEdit)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept)
        self.buttonBox.rejected.connect(Dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(Dialog)
        Dialog.setTabOrder(self.RaHours, self.RaMinutes)
        Dialog.setTabOrder(self.RaMinutes, self.RaSeconds)
        Dialog.setTabOrder(self.RaSeconds, self.DecDegrees)
        Dialog.setTabOrder(self.DecDegrees, self.DecMinutes)
        Dialog.setTabOrder(self.DecMinutes, self.DecSeconds)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label.setText(_translate("Dialog", "RA"))
        self.label_5.setText(_translate("Dialog", "Dec"))
        self.label_6.setText(_translate("Dialog", "degrees"))
        self.label_7.setText(_translate("Dialog", "minutes"))
        self.label_8.setText(_translate("Dialog", "seconds"))
        self.label_9.setText(_translate("Dialog", "<html><head/><body><p>Set/Confirm ICRS J2000 coordinates for occulted star</p></body></html>"))
        self.label_11.setText(_translate("Dialog", "<html><head/><body><p>Alternative single line entry (eases copy and paste from VizieR query):</p><p>Use form <span style=\" font-weight:600; color:#fc0107;\">6h32m45.66s -23d31m29.11s</span> (<span style=\" color:#000000;\">the +/- sign for Dec </span><span style=\" font-weight:600; font-style:italic; text-decoration: underline; color:#fc0107;\">MUST</span><span style=\" color:#000000;\">  be present !!</span>)</p></body></html>"))
        self.label_2.setText(_translate("Dialog", "hours"))
        self.label_3.setText(_translate("Dialog", "minutes"))
        self.label_4.setText(_translate("Dialog", "seconds"))
        self.label_10.setText(_translate("Dialog", "nova.astrometry.net API key:"))
        self.label_12.setText(_translate("Dialog", "Star coordinates (hmsdms)"))


